@@ -1,4 +1,4 @@
-svg.transform <- function(tmarr, applyto = '', times = NULL, add = FALSE, regexp = FALSE){
+svg.transform <- function(tmarr, applyto = '', times = NULL, regexp = FALSE){
 
 	# If times is null, set based on dimensions of tmarr
 	if(is.null(times)){
@@ -36,13 +36,13 @@ svg.transform <- function(tmarr, applyto = '', times = NULL, add = FALSE, regexp
 
 			# Apply each body transform in array
 			if(length(dim(tmarr)) == 6){
-				svg.transform(tmarr=tmarr[, , i, , , ], applyto=applyto[i], times=times, add=add, regexp=regexp)
+				svg.transform(tmarr=tmarr[, , i, , , ], applyto=applyto[i], times=times, regexp=regexp)
 			}else if(length(dim(tmarr)) == 5){
-				svg.transform(tmarr=tmarr[, , i, , ], applyto=applyto[i], times=times, add=add, regexp=regexp)
+				svg.transform(tmarr=tmarr[, , i, , ], applyto=applyto[i], times=times, regexp=regexp)
 			}else if(length(dim(tmarr)) == 4){
-				svg.transform(tmarr=tmarr[, , i, ], applyto=applyto[i], times=times, add=add, regexp=regexp)
+				svg.transform(tmarr=tmarr[, , i, ], applyto=applyto[i], times=times, regexp=regexp)
 			}else if(length(dim(tmarr)) == 3){
-				svg.transform(tmarr=tmarr[, , i], applyto=applyto[i], add=add, regexp=regexp)
+				svg.transform(tmarr=tmarr[, , i], applyto=applyto[i], regexp=regexp)
 			}else{
 				stop("Unrecognized number of dimensions for tmarr.")
 			}
@@ -60,7 +60,7 @@ svg.transform <- function(tmarr, applyto = '', times = NULL, add = FALSE, regexp
 		ref_names <- svgviewr_env$ref$names
 		ref_types <- svgviewr_env$ref$type
 		ref_nums <- svgviewr_env$ref$num
-
+		
 		# Get matching names
 		if(!regexp){
 
@@ -73,6 +73,11 @@ svg.transform <- function(tmarr, applyto = '', times = NULL, add = FALSE, regexp
 			applyto_which <- c()
 			for(i in 1:length(applyto)) applyto_which <- c(applyto_which, which(grepl(applyto[i], ref_names)))
 		}
+		
+		#print(length(ref_names))
+		#print(length(ref_types))
+		#print(applyto)
+		#print(applyto_which)
 
 		# Make sure name was found
 		if(length(applyto_which) == 0){
@@ -144,9 +149,9 @@ svg.transform <- function(tmarr, applyto = '', times = NULL, add = FALSE, regexp
 			# Define number of animation iterations and times if not already defined
 			if(is.null(svgviewr_env$svg$animate$times)) svgviewr_env$svg$animate$times <- times
 			
-			# For each object for which position will become 
+			# For each object for which position will become
 			for(idx in applyto_which){
-
+				
 				if(ref_types[idx] == 'mesh'){
 
 					if(length(dim(tmarr)) == 5){
@@ -169,7 +174,7 @@ svg.transform <- function(tmarr, applyto = '', times = NULL, add = FALSE, regexp
 						for(dim1 in 1:n_dim1){
 							quaternion[[dim1]] <- list()
 							for(dim2 in 1:n_dim2){
-								quaternion[[dim1]][[dim2]] <- lapply(seq_len(dim(tmarr)[3]), function(i) as.list(setNames(-(signif(round(RM2Quat(t(tmarr[1:3, 1:3, dim1, dim2, i])),10), digits=env[['svgviewr_env']][['js_var']][['signif_digits']])), c('x','y','z','w'))))
+								quaternion[[dim1]][[dim2]] <- lapply(seq_len(dim(tmarr)[3]), function(i) as.list(setNames(-(signif(round(RM2Quat_svg(t(tmarr[1:3, 1:3, dim1, dim2, i])),10), digits=env[['svgviewr_env']][['js_var']][['signif_digits']])), c('x','y','z','w'))))
 							}
 						}
 
@@ -185,21 +190,30 @@ svg.transform <- function(tmarr, applyto = '', times = NULL, add = FALSE, regexp
 						# Set quaternion
 						quaternion <- list()
 						for(dim1 in 1:n_dim1){
-							quaternion[[dim1]] <- lapply(seq_len(dim(tmarr)[3]), function(i) as.list(setNames(-(signif(round(RM2Quat(t(tmarr[1:3, 1:3, dim1, i])),10), digits=env[['svgviewr_env']][['js_var']][['signif_digits']])), c('x','y','z','w'))))
+							quaternion[[dim1]] <- lapply(seq_len(dim(tmarr)[3]), function(i) as.list(setNames(-(signif(round(RM2Quat_svg(t(tmarr[1:3, 1:3, dim1, i])),10), digits=env[['svgviewr_env']][['js_var']][['signif_digits']])), c('x','y','z','w'))))
 						}
 
 					}else if(length(dim(tmarr)) == 3){
-						
+
+						if(!is.null(svgviewr_env[['svg']][[ref_types[idx]]][[ref_nums[idx]]][['itmat']])){
+							tmarr_new <- tmarr
+							for(iter in 1:dim(tmarr)[3]){
+								tmarr_new[,,iter] <- tmarr[,,iter] %*% svgviewr_env[['svg']][[ref_types[idx]]][[ref_nums[idx]]][['itmat']]
+							}
+						}else{
+							tmarr_new <- tmarr
+						}
+
 						# Set position
-						position <- lapply(seq_len(dim(tmarr)[3]), function(i) as.list(setNames(signif(tmarr[1:3, 4, i], digits=env[['svgviewr_env']][['js_var']][['signif_digits']]), c('x', 'y', 'z'))))
+						position <- lapply(seq_len(dim(tmarr_new)[3]), function(i) as.list(setNames(signif(tmarr_new[1:3, 4, i], digits=env[['svgviewr_env']][['js_var']][['signif_digits']]), c('x', 'y', 'z'))))
 						#if(idx == applyto_which[1]) print(position)
 
 						# Set rotation
-						#rotation <- lapply(seq_len(dim(tmarr)[3]), function(i) -rev(signif(rm2euler(t(tmarr[1:3, 1:3, i]))[[1]], digits=env[['svgviewr_env']][['js_var']][['signif_digits']])))
+						#rotation <- lapply(seq_len(dim(tmarr_new)[3]), function(i) -rev(signif(rm2euler(t(tmarr_new[1:3, 1:3, i]))[[1]], digits=env[['svgviewr_env']][['js_var']][['signif_digits']])))
 
 						# Set quaternion
-						#quaternion <- lapply(seq_len(dim(tmarr)[3]), function(i) matrix(-(signif(round(RM2Quat(t(tmarr[1:3, 1:3, i])),10), digits=env[['svgviewr_env']][['js_var']][['signif_digits']])), 4, 1, dimnames=list(c('x','y','z','w'), NULL)))
-						quaternion <- lapply(seq_len(dim(tmarr)[3]), function(i) as.list(setNames(-(signif(round(RM2Quat(t(tmarr[1:3, 1:3, i])),10), digits=env[['svgviewr_env']][['js_var']][['signif_digits']])), c('x','y','z','w'))))
+						#quaternion <- lapply(seq_len(dim(tmarr_new)[3]), function(i) matrix(-(signif(round(RM2Quat_svg(t(tmarr_new[1:3, 1:3, i])),10), digits=env[['svgviewr_env']][['js_var']][['signif_digits']])), 4, 1, dimnames=list(c('x','y','z','w'), NULL)))
+						quaternion <- lapply(seq_len(dim(tmarr_new)[3]), function(i) as.list(setNames(-(signif(round(RM2Quat_svg(t(tmarr_new[1:3, 1:3, i])),10), digits=env[['svgviewr_env']][['js_var']][['signif_digits']])), c('x','y','z','w'))))
 
 					}else{
 
@@ -209,7 +223,7 @@ svg.transform <- function(tmarr, applyto = '', times = NULL, add = FALSE, regexp
 					# Save transformations
 					svgviewr_env[['svg']][[ref_types[idx]]][[ref_nums[idx]]][['position']] <- position
 					svgviewr_env[['svg']][[ref_types[idx]]][[ref_nums[idx]]][['quaternion']] <- quaternion
-					svgviewr_env[['svg']][[ref_types[idx]]][[ref_nums[idx]]][['tmat']] <- tmarr
+					svgviewr_env[['svg']][[ref_types[idx]]][[ref_nums[idx]]][['tmat']] <- tmarr_new
 
 				}else if(ref_types[idx] == 'sphere'){
 				
